@@ -126,7 +126,7 @@ type absOutputValueUniqueKey string
 func (k absOutputValueUniqueKey) uniqueKeySigil() {}
 
 func ParseAbsOutputValue(traversal hcl.Traversal) (AbsOutputValue, tfdiags.Diagnostics) {
-	path, remain, diags := parseModuleInstancePrefix(traversal)
+	path, remain, diags := parseModuleInstancePrefix(traversal, false)
 	if diags.HasErrors() {
 		return AbsOutputValue{}, diags
 	}
