@@ -177,6 +177,9 @@ func parseResourceInstanceUnderModule(moduleAddr ModuleInstance, allowPartial bo
 	case "ephemeral":
 		mode = EphemeralResourceMode
 		remain = remain[1:]
+	case "list":
+		mode = ListResourceMode
+		remain = remain[1:]
 	case "resource":
 		// Starting a resource address with "resource" is optional, so we'll
 		// just ignore it.
@@ -231,6 +234,13 @@ func parseResourceInstanceUnderModule(moduleAddr ModuleInstance, allowPartial bo
 				Detail:   "An ephemeral resource type name is required.",
 				Subject:  remain[0].SourceRange().Ptr(),
 			})
+		case ListResourceMode:
+			diags = diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Invalid address",
+				Detail:   "A list resource type name is required.",
+				Subject:  remain[0].SourceRange().Ptr(),
+			})
 		default:
 			panic("unknown mode")
 		}
