@@ -64,7 +64,7 @@ func Test_cloud_run_variables(t *testing.T) {
 					commands: []tfCommand{
 						{
 							command:           []string{"init"},
-							expectedCmdOutput: `Terraform Cloud has been successfully initialized!`,
+							expectedCmdOutput: `HCP Terraform has been successfully initialized!`,
 						},
 						{
 							command:           []string{"plan", "-var", "foo=bar"},
