@@ -4,7 +4,7 @@
 package command
 
 import (
-	"github.com/hashicorp/terraform/internal/backend"
+	"github.com/hashicorp/terraform/internal/backend/backendrun"
 	"github.com/hashicorp/terraform/internal/cloud"
 )
 
@@ -12,7 +12,7 @@ const failedToLoadSchemasMessage = `
 Warning: Failed to update data for external integrations
 
 Terraform was unable to generate a description of the updated
-state for use with external integrations in Terraform Cloud.
+state for use with external integrations in HCP Terraform or Terraform Enterprise.
 Any integrations configured for this workspace which depend on
 information from the state may not work correctly when using the
 result of this action.
@@ -24,7 +24,7 @@ of the state:
     terraform apply
 `
 
-func isCloudMode(b backend.Enhanced) bool {
+func isCloudMode(b backendrun.OperationsBackend) bool {
 	_, ok := b.(*cloud.Cloud)
 
 	return ok
