@@ -43,6 +43,8 @@ type JSONLog struct {
 	TestFatalInterrupt *viewsjson.TestFatalInterrupt `json:"test_interrupt,omitempty"`
 	TestState          *State                        `json:"test_state,omitempty"`
 	TestPlan           *Plan                         `json:"test_plan,omitempty"`
+
+	ListQueryResult *viewsjson.QueryResult `json:"list_resource_found,omitempty"`
 }
 
 const (
@@ -78,6 +80,10 @@ const (
 	LogTestInterrupt JSONLogType = "test_interrupt"
 	LogTestStatus    JSONLogType = "test_status"
 	LogTestRetry     JSONLogType = "test_retry"
+
+	// Query Messages
+	LogListStart         JSONLogType = "list_start"
+	LogListResourceFound JSONLogType = "list_resource_found"
 )
 
 func incompatibleVersions(localVersion, remoteVersion string) bool {
@@ -156,7 +162,8 @@ func (renderer Renderer) RenderLog(log *JSONLog) error {
 		LogTestRetry,
 		LogTestPlan,
 		LogTestState,
-		LogTestInterrupt:
+		LogTestInterrupt,
+		LogListStart:
 		// We won't display these types of logs
 		return nil
 
@@ -290,6 +297,15 @@ func (renderer Renderer) RenderLog(log *JSONLog) error {
 			}
 		}
 
+	case LogListResourceFound:
+		// TODO: revisit once the cloud backend support list runs
+		// We will need to transform the identity to a more human-readable form
+		result := log.ListQueryResult
+		renderer.Streams.Printf("%s\t%s\t%s\n",
+			result.Address,
+			result.Identity,
+			result.DisplayName)
+
 	default:
 		// If the log type is not a known log type, we will just print the log message
 		renderer.Streams.Println(log.Message)
