@@ -10,6 +10,7 @@ import (
 	"os"
 
 	"github.com/hashicorp/terraform/internal/addrs"
+	"github.com/hashicorp/terraform/internal/command/arguments"
 	"github.com/hashicorp/terraform/internal/depsfile"
 	"github.com/hashicorp/terraform/internal/getproviders"
 	"github.com/hashicorp/terraform/internal/providercache"
@@ -40,12 +41,14 @@ func (c *ProvidersLockCommand) Synopsis() string {
 func (c *ProvidersLockCommand) Run(args []string) int {
 	args = c.Meta.process(args)
 	cmdFlags := c.Meta.defaultFlagSet("providers lock")
-	var optPlatforms FlagStringSlice
+	var optPlatforms arguments.FlagStringSlice
 	var fsMirrorDir string
 	var netMirrorURL string
+
 	cmdFlags.Var(&optPlatforms, "platform", "target platform")
 	cmdFlags.StringVar(&fsMirrorDir, "fs-mirror", "", "filesystem mirror directory")
 	cmdFlags.StringVar(&netMirrorURL, "net-mirror", "", "network mirror base URL")
+	pluginCache := cmdFlags.Bool("enable-plugin-cache", false, "")
 	cmdFlags.Usage = func() { c.Ui.Error(c.Help()) }
 	if err := cmdFlags.Parse(args); err != nil {
 		c.Ui.Error(fmt.Sprintf("Error parsing command-line flags: %s\n", err.Error()))
@@ -246,6 +249,13 @@ func (c *ProvidersLockCommand) Run(args []string) int {
 		dir := providercache.NewDirWithPlatform(tempDir, platform)
 		installer := providercache.NewInstaller(dir, source)
 
+		// Use global plugin cache for extra speed if present and flag is set
+		globalCacheDir := c.providerGlobalCacheDir()
+		if *pluginCache && globalCacheDir != nil {
+			installer.SetGlobalCacheDir(globalCacheDir.WithPlatform(platform))
+			installer.SetGlobalCacheDirMayBreakDependencyLockFile(c.PluginCacheMayBreakDependencyLockFile)
+		}
+
 		newLocks, err := installer.EnsureProviderVersions(ctx, oldLocks, reqs, providercache.InstallNewProvidersForce)
 		if err != nil {
 			diags = diags.Append(tfdiags.Sourceless(
@@ -370,38 +380,42 @@ Usage: terraform [global options] providers lock [options] [providers...]
 
 Options:
 
-  -fs-mirror=dir     Consult the given filesystem mirror directory instead
-                     of the origin registry for each of the given providers.
+  -fs-mirror=dir         Consult the given filesystem mirror directory instead
+                         of the origin registry for each of the given providers.
 
-                     This would be necessary to generate lock file entries for
-                     a provider that is available only via a mirror, and not
-                     published in an upstream registry. In this case, the set
-                     of valid checksums will be limited only to what Terraform
-                     can learn from the data in the mirror directory.
+                         This would be necessary to generate lock file entries for
+                         a provider that is available only via a mirror, and not
+                         published in an upstream registry. In this case, the set
+                         of valid checksums will be limited only to what Terraform
+                         can learn from the data in the mirror directory.
 
-  -net-mirror=url    Consult the given network mirror (given as a base URL)
-                     instead of the origin registry for each of the given
-                     providers.
+  -net-mirror=url        Consult the given network mirror (given as a base URL)
+                         instead of the origin registry for each of the given
+                         providers.
 
-                     This would be necessary to generate lock file entries for
-                     a provider that is available only via a mirror, and not
-                     published in an upstream registry. In this case, the set
-                     of valid checksums will be limited only to what Terraform
-                     can learn from the data in the mirror indices.
+                         This would be necessary to generate lock file entries for
+                         a provider that is available only via a mirror, and not
+                         published in an upstream registry. In this case, the set
+                         of valid checksums will be limited only to what Terraform
+                         can learn from the data in the mirror indices.
 
-  -platform=os_arch  Choose a target platform to request package checksums
-                     for.
+  -platform=os_arch      Choose a target platform to request package checksums
+                         for.
 
-                     By default Terraform will request package checksums
-                     suitable only for the platform where you run this
-                     command. Use this option multiple times to include
-                     checksums for multiple target systems.
+                         By default Terraform will request package checksums
+                         suitable only for the platform where you run this
+                         command. Use this option multiple times to include
+                         checksums for multiple target systems.
 
-                     Target names consist of an operating system and a CPU
-                     architecture. For example, "linux_amd64" selects the
-                     Linux operating system running on an AMD64 or x86_64
-                     CPU. Each provider is available only for a limited
-                     set of target platforms.
+                         Target names consist of an operating system and a CPU
+                         architecture. For example, "linux_amd64" selects the
+                         Linux operating system running on an AMD64 or x86_64
+                         CPU. Each provider is available only for a limited
+                         set of target platforms.
+
+  -enable-plugin-cache   Enable the usage of the globally configured plugin cache.
+                         This will speed up the locking process, but the providers
+                         wont be loaded from an authoritative source.
 `
 }
 
