@@ -8,10 +8,10 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/hashicorp/cli"
 	"github.com/hashicorp/terraform/internal/backend"
 	"github.com/hashicorp/terraform/internal/backend/remote-state/inmem"
 	"github.com/hashicorp/terraform/internal/states"
-	"github.com/mitchellh/cli"
 )
 
 func TestStatePush_empty(t *testing.T) {
