@@ -161,7 +161,7 @@ func (c *VersionCommand) Run(args []string) int {
 		if outdated {
 			c.Ui.Output(fmt.Sprintf(
 				"\nYour version of Terraform is out of date! The latest version\n"+
-					"is %s. You can update by downloading from https://www.terraform.io/downloads.html",
+					"is %s. You can update by downloading from https://developer.hashicorp.com/terraform/install",
 				latest))
 		}
 
