@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: BUSL-1.1
+
 package views
 
 import (
@@ -100,16 +103,24 @@ func TestApplyHuman_help(t *testing.T) {
 // Hooks and ResourceCount are tangled up and easiest to test together.
 func TestApply_resourceCount(t *testing.T) {
 	testCases := map[string]struct {
-		destroy bool
-		want    string
+		destroy   bool
+		want      string
+		importing bool
 	}{
 		"apply": {
 			false,
 			"Apply complete! Resources: 1 added, 2 changed, 3 destroyed.",
+			false,
 		},
 		"destroy": {
 			true,
 			"Destroy complete! Resources: 3 destroyed.",
+			false,
+		},
+		"import": {
+			false,
+			"Apply complete! Resources: 1 imported, 1 added, 2 changed, 3 destroyed.",
+			true,
 		},
 	}
 
@@ -138,6 +149,10 @@ func TestApply_resourceCount(t *testing.T) {
 				count.Changed = 2
 				count.Removed = 3
 
+				if tc.importing {
+					count.Imported = 1
+				}
+
 				v.ResourceCount("")
 
 				got := done(t).Stdout()
@@ -246,7 +261,6 @@ func TestApplyJSON_outputs(t *testing.T) {
 				},
 				"password": map[string]interface{}{
 					"sensitive": true,
-					"value":     "horse-battery",
 					"type":      "string",
 				},
 			},
