@@ -199,7 +199,7 @@ func (t *TestHuman) Run(run *moduletest.Run, file *moduletest.File, progress mod
 					ProviderFormatVersion: jsonprovider.FormatVersion,
 					RootModule:            root,
 					RootModuleOutputs:     outputs,
-					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas),
+					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas, false),
 				}
 
 				t.view.streams.Println() // Separate the state from any previous statements.
@@ -221,7 +221,7 @@ func (t *TestHuman) Run(run *moduletest.Run, file *moduletest.File, progress mod
 					OutputChanges:         outputs,
 					ResourceChanges:       changed,
 					ResourceDrift:         drift,
-					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas),
+					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas, false),
 					RelevantAttributes:    attrs,
 				}
 
@@ -560,7 +560,7 @@ func (t *TestJSON) Run(run *moduletest.Run, file *moduletest.File, progress modu
 					ProviderFormatVersion: jsonprovider.FormatVersion,
 					RootModule:            root,
 					RootModuleOutputs:     outputs,
-					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas),
+					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas, false),
 				}
 
 				t.view.log.Info(
@@ -584,7 +584,7 @@ func (t *TestJSON) Run(run *moduletest.Run, file *moduletest.File, progress modu
 					OutputChanges:         outputs,
 					ResourceChanges:       changed,
 					ResourceDrift:         drift,
-					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas),
+					ProviderSchemas:       jsonprovider.MarshalForRenderer(schemas, false),
 					RelevantAttributes:    attrs,
 				}
 
