@@ -107,6 +107,14 @@ func (o *Object) ImpliedType() cty.Type {
 	return o.specType().WithoutOptionalAttributesDeep()
 }
 
+// ConfigType returns a cty.Type that can be used to decode a configuration
+// object using the receiving block schema.
+//
+// ConfigType will preserve optional attributes
+func (o *Object) ConfigType() cty.Type {
+	return o.specType()
+}
+
 // specType returns the cty.Type used for decoding a NestedType Attribute using
 // the receiving block schema.
 func (o *Object) specType() cty.Type {
