@@ -34,6 +34,7 @@ type Module struct {
 	ActiveExperiments experiments.Set
 
 	Backend              *Backend
+	StateStore           *StateStore
 	CloudConfig          *CloudConfig
 	ProviderConfigs      map[string]*Provider
 	ProviderRequirements *RequiredProviders
@@ -49,6 +50,8 @@ type Module struct {
 	ManagedResources   map[string]*Resource
 	DataResources      map[string]*Resource
 	EphemeralResources map[string]*Resource
+	ListResources      map[string]*Resource
+	Actions            map[string]*Action
 
 	Moved   []*Moved
 	Removed []*Removed
@@ -76,6 +79,7 @@ type File struct {
 	ActiveExperiments experiments.Set
 
 	Backends          []*Backend
+	StateStores       []*StateStore
 	CloudConfigs      []*CloudConfig
 	ProviderConfigs   []*Provider
 	ProviderMetas     []*ProviderMeta
@@ -95,7 +99,8 @@ type File struct {
 	Removed []*Removed
 	Import  []*Import
 
-	Checks []*Check
+	Checks  []*Check
+	Actions []*Action
 }
 
 // NewModuleWithTests matches NewModule except it will also load in the provided
@@ -128,9 +133,11 @@ func NewModule(primaryFiles, overrideFiles []*File) (*Module, hcl.Diagnostics) {
 		ManagedResources:   map[string]*Resource{},
 		EphemeralResources: map[string]*Resource{},
 		DataResources:      map[string]*Resource{},
+		ListResources:      map[string]*Resource{},
 		Checks:             map[string]*Check{},
 		ProviderMetas:      map[addrs.Provider]*ProviderMeta{},
 		Tests:              map[string]*TestFile{},
+		Actions:            map[string]*Action{},
 	}
 
 	// Process the required_providers blocks first, to ensure that all
@@ -197,6 +204,8 @@ func (m *Module) ResourceByAddr(addr addrs.Resource) *Resource {
 		return m.DataResources[key]
 	case addrs.EphemeralResourceMode:
 		return m.EphemeralResources[key]
+	case addrs.ListResourceMode:
+		return m.ListResources[key]
 	default:
 		return nil
 	}
@@ -215,15 +224,30 @@ func (m *Module) appendFile(file *File) hcl.Diagnostics {
 		if m.Backend != nil {
 			diags = append(diags, &hcl.Diagnostic{
 				Severity: hcl.DiagError,
-				Summary:  "Duplicate backend configuration",
-				Detail:   fmt.Sprintf("A module may have only one backend configuration. The backend was previously configured at %s.", m.Backend.DeclRange),
+				Summary:  "Duplicate 'backend' configuration block",
+				Detail:   fmt.Sprintf("A module may have only one 'backend' configuration block. The backend was previously configured at %s.", m.Backend.DeclRange),
 				Subject:  &b.DeclRange,
 			})
 			continue
 		}
+
 		m.Backend = b
 	}
 
+	for _, ss := range file.StateStores {
+		if m.StateStore != nil {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Duplicate 'state_store' configuration block",
+				Detail:   fmt.Sprintf("A module may have only one 'state_store' configuration block. The state store was previously configured at %s.", m.StateStore.DeclRange),
+				Subject:  &ss.DeclRange,
+			})
+			continue
+		}
+
+		m.StateStore = ss
+	}
+
 	for _, c := range file.CloudConfigs {
 		if m.CloudConfig != nil {
 			diags = append(diags, &hcl.Diagnostic{
@@ -238,12 +262,43 @@ func (m *Module) appendFile(file *File) hcl.Diagnostics {
 		m.CloudConfig = c
 	}
 
-	if m.Backend != nil && m.CloudConfig != nil {
+	// Handle conflicting blocks of different types
+	switch {
+	case m.CloudConfig != nil && m.StateStore != nil && m.Backend != nil:
 		diags = append(diags, &hcl.Diagnostic{
 			Severity: hcl.DiagError,
-			Summary:  "Both a backend and cloud configuration are present",
-			Detail:   fmt.Sprintf("A module may declare either one 'cloud' block OR one 'backend' block configuring a state backend. The 'cloud' block is configured at %s; a backend is configured at %s. Remove the backend block to configure HCP Terraform or Terraform Enteprise.", m.CloudConfig.DeclRange, m.Backend.DeclRange),
-			Subject:  &m.Backend.DeclRange,
+			Summary:  "Only one of 'cloud', 'state_store', or 'backend' configuration blocks are allowed",
+			Detail: fmt.Sprintf("A module may only declare one 'cloud', 'state_store' OR 'backend' block when configuring state storage. "+
+				"The 'cloud' block is configured at %s; a 'state_store' is configured at %s; a 'backend' is configured at %s. Remove two of these blocks.",
+				m.CloudConfig.DeclRange, m.StateStore.DeclRange, m.Backend.DeclRange),
+			Subject: &m.Backend.DeclRange,
+		})
+	case m.CloudConfig != nil && m.Backend != nil:
+		diags = append(diags, &hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  "Conflicting 'cloud' and 'backend' configuration blocks are present",
+			Detail: fmt.Sprintf("A module may declare either one 'cloud' block OR one 'backend' block for configuring state storage. "+
+				"The 'cloud' block is configured at %s; a 'backend' is configured at %s. Remove the 'backend' block to configure HCP Terraform or Terraform Enterprise.",
+				m.CloudConfig.DeclRange, m.Backend.DeclRange),
+			Subject: &m.Backend.DeclRange,
+		})
+	case m.CloudConfig != nil && m.StateStore != nil:
+		diags = append(diags, &hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  "Conflicting 'cloud' and 'state_store' configuration blocks are present",
+			Detail: fmt.Sprintf("A module may declare either one 'cloud' block OR one 'state_store' block for configuring state storage. "+
+				"A 'cloud' block is configured at %s; a 'state_store' is configured at %s. Remove the 'state_store' block to configure HCP Terraform or Terraform Enterprise.",
+				m.CloudConfig.DeclRange, m.StateStore.DeclRange),
+			Subject: &m.StateStore.DeclRange,
+		})
+	case m.StateStore != nil && m.Backend != nil:
+		diags = append(diags, &hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  "Conflicting 'state_store' and 'backend' configuration blocks are present",
+			Detail: fmt.Sprintf("A module may declare either one 'state_store' block OR one 'backend' block when configuring state storage. "+
+				"A 'state_store' block is configured at %s; a 'backend' is configured at %s. Remove one of these blocks.",
+				m.StateStore.DeclRange, m.Backend.DeclRange),
+			Subject: &m.Backend.DeclRange,
 		})
 	}
 
@@ -491,6 +546,104 @@ func (m *Module) appendFile(file *File) hcl.Diagnostics {
 		m.Import = append(m.Import, i)
 	}
 
+	for _, a := range file.Actions {
+		key := a.moduleUniqueKey()
+		if existing, exists := m.Actions[key]; exists {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  fmt.Sprintf("Duplicate action %q configuration", existing.Type),
+				Detail:   fmt.Sprintf("An action named %q was already declared at %s. Resource names must be unique per type in each module.", existing.Name, existing.DeclRange),
+				Subject:  &a.DeclRange,
+			})
+			continue
+		}
+		m.Actions[key] = a
+
+		// set the provider FQN for the action
+		if a.ProviderConfigRef != nil {
+			a.Provider = m.ProviderForLocalConfig(a.ProviderConfigAddr())
+		} else {
+			// an invalid resource name (for e.g. "null resource" instead of
+			// "null_resource") can cause a panic down the line in addrs:
+			// https://github.com/hashicorp/terraform/issues/25560
+			implied, err := addrs.ParseProviderPart(a.Addr().ImpliedProvider())
+			if err == nil {
+				a.Provider = m.ImpliedProviderForUnqualifiedType(implied)
+			}
+			// We don't return a diagnostic because the invalid resource name
+			// will already have been caught.
+		}
+	}
+
+	return diags
+}
+
+func (m *Module) appendQueryFile(file *QueryFile) hcl.Diagnostics {
+	var diags hcl.Diagnostics
+
+	for _, pc := range file.ProviderConfigs {
+		key := pc.moduleUniqueKey()
+		if existing, exists := m.ProviderConfigs[key]; exists {
+			if existing.Alias == "" {
+				diags = append(diags, &hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Duplicate provider configuration",
+					Detail:   fmt.Sprintf("A default (non-aliased) provider configuration for %q was already given at %s. If multiple configurations are required, set the \"alias\" argument for alternative configurations.", existing.Name, existing.DeclRange),
+					Subject:  &pc.DeclRange,
+				})
+			} else {
+				diags = append(diags, &hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Duplicate provider configuration",
+					Detail:   fmt.Sprintf("A provider configuration for %q with alias %q was already given at %s. Each configuration for the same provider must have a distinct alias.", existing.Name, existing.Alias, existing.DeclRange),
+					Subject:  &pc.DeclRange,
+				})
+			}
+			continue
+		}
+		m.ProviderConfigs[key] = pc
+	}
+
+	for _, v := range file.Variables {
+		if existing, exists := m.Variables[v.Name]; exists {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Duplicate variable declaration",
+				Detail:   fmt.Sprintf("A variable named %q was already declared at %s. Variable names must be unique within a module.", existing.Name, existing.DeclRange),
+				Subject:  &v.DeclRange,
+			})
+		}
+		m.Variables[v.Name] = v
+	}
+
+	for _, l := range file.Locals {
+		if existing, exists := m.Locals[l.Name]; exists {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Duplicate local value definition",
+				Detail:   fmt.Sprintf("A local value named %q was already defined at %s. Local value names must be unique within a module.", existing.Name, existing.DeclRange),
+				Subject:  &l.DeclRange,
+			})
+		}
+		m.Locals[l.Name] = l
+	}
+
+	for _, ql := range file.ListResources {
+		key := ql.moduleUniqueKey()
+		if existing, exists := m.ListResources[key]; exists {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  fmt.Sprintf("Duplicate list %q configuration", existing.Type),
+				Detail:   fmt.Sprintf("A %s list named %q was already declared at %s. List names must be unique per type in each module.", existing.Type, existing.Name, existing.DeclRange),
+				Subject:  &ql.DeclRange,
+			})
+			continue
+		}
+		// set the provider FQN for the resource
+		m.ListResources[key] = ql
+		ql.Provider = m.ProviderForLocalConfig(ql.ProviderConfigAddr())
+	}
+
 	return diags
 }
 
@@ -508,8 +661,11 @@ func (m *Module) mergeFile(file *File) hcl.Diagnostics {
 	if len(file.Backends) != 0 {
 		switch len(file.Backends) {
 		case 1:
-			m.CloudConfig = nil // A backend block is mutually exclusive with a cloud one, and overwrites any cloud config
+			// The cloud, state_store, and backend blocks are mutually exclusive
+			// By setting a backend we must unset others
 			m.Backend = file.Backends[0]
+			m.CloudConfig = nil
+			m.StateStore = nil
 		default:
 			// An override file with multiple backends is still invalid, even
 			// though it can override backends from _other_ files.
@@ -522,11 +678,34 @@ func (m *Module) mergeFile(file *File) hcl.Diagnostics {
 		}
 	}
 
+	if len(file.StateStores) != 0 {
+		switch len(file.StateStores) {
+		case 1:
+			// The cloud, state_store, and backend blocks are mutually exclusive
+			// By setting a state_store we must unset others
+			m.Backend = nil
+			m.CloudConfig = nil
+			m.StateStore = file.StateStores[0]
+		default:
+			// An override file with multiple state storages is still invalid, even
+			// though it can override state storages from _other_ files.
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Duplicate state storage configuration",
+				Detail:   fmt.Sprintf("Each override file may have only one state storage configuration. A state storage was previously configured at %s.", file.StateStores[0].DeclRange),
+				Subject:  &file.StateStores[1].DeclRange,
+			})
+		}
+	}
+
 	if len(file.CloudConfigs) != 0 {
 		switch len(file.CloudConfigs) {
 		case 1:
-			m.Backend = nil // A cloud block is mutually exclusive with a backend one, and overwrites any backend
+			// The cloud, state_store, and backend blocks are mutually exclusive
+			// By setting a cloud block we must unset others
+			m.Backend = nil
 			m.CloudConfig = file.CloudConfigs[0]
+			m.StateStore = nil
 		default:
 			// An override file with multiple cloud blocks is still invalid, even
 			// though it can override cloud/backend blocks from _other_ files.
@@ -681,6 +860,22 @@ func (m *Module) mergeFile(file *File) hcl.Diagnostics {
 		})
 	}
 
+	for _, a := range file.Actions {
+		key := a.moduleUniqueKey()
+		existing, exists := m.Actions[key]
+		if !exists {
+			diags = append(diags, &hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "Missing resource to override",
+				Detail:   fmt.Sprintf("There is no action named %q. An override file can only override a resource block defined in a primary configuration file.", a.Name),
+				Subject:  &a.DeclRange,
+			})
+			continue
+		}
+		mergeDiags := existing.merge(a, m.ProviderRequirements.RequiredProviders)
+		diags = append(diags, mergeDiags...)
+	}
+
 	return diags
 }
 
