@@ -7,15 +7,19 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 	"testing"
 	"time"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
+	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/experiments"
 	"github.com/hashicorp/terraform/internal/lang/marks"
 	homedir "github.com/mitchellh/go-homedir"
 	"github.com/zclconf/go-cty/cty"
+	"github.com/zclconf/go-cty/cty/function"
+	"github.com/zclconf/go-cty/cty/function/stdlib"
 )
 
 // TestFunctions tests that functions are callable through the functionality
@@ -359,6 +363,17 @@ func TestFunctions(t *testing.T) {
 			},
 		},
 
+		"ephemeralasnull": {
+			{
+				`ephemeralasnull(local.ephemeral)`,
+				cty.NullVal(cty.String),
+			},
+			{
+				`ephemeralasnull("not ephemeral")`,
+				cty.StringVal("not ephemeral"),
+			},
+		},
+
 		"file": {
 			{
 				`file("hello.txt")`,
@@ -512,6 +527,13 @@ func TestFunctions(t *testing.T) {
 			},
 		},
 
+		"issensitive": {
+			{
+				`issensitive(1)`,
+				cty.False,
+			},
+		},
+
 		"join": {
 			{
 				`join(" ", ["Hello", "World"])`,
@@ -960,6 +982,25 @@ func TestFunctions(t *testing.T) {
 				`templatefile("hello.tmpl", {name = "Jodie"})`,
 				cty.StringVal("Hello, Jodie!"),
 			},
+			{
+				`core::templatefile("hello.tmpl", {name = "Namespaced Jodie"})`,
+				cty.StringVal("Hello, Namespaced Jodie!"),
+			},
+		},
+
+		"templatestring": {
+			{
+				`templatestring(local.greeting_template, {
+  name = "Arthur"
+})`,
+				cty.StringVal("Hello, Arthur!"),
+			},
+			{
+				`core::templatestring(local.greeting_template, {
+  name = "Namespaced Arthur"
+})`,
+				cty.StringVal("Hello, Namespaced Arthur!"),
+			},
 		},
 
 		"timeadd": {
@@ -1100,6 +1141,10 @@ func TestFunctions(t *testing.T) {
 				`upper("hello")`,
 				cty.StringVal("HELLO"),
 			},
+			{
+				`core::upper("hello")`,
+				cty.StringVal("HELLO"),
+			},
 		},
 
 		"urlencode": {
@@ -1184,16 +1229,40 @@ func TestFunctions(t *testing.T) {
 				}),
 			},
 		},
+		// External function dispatching tests. These ones are only here to
+		// test that dispatching to externally-declared functions works
+		// _at all_, using just some placeholder functions declared in the
+		// test code below.
+		"provider::foo::upper": {
+			{
+				`provider::foo::upper("hello")`,
+				cty.StringVal("HELLO"),
+			},
+		},
 	}
 
 	experimentalFuncs := map[string]experiments.Experiment{}
-	experimentalFuncs["defaults"] = experiments.ModuleVariableOptionalAttrs
+
+	// We'll also register a few "external functions" so that we can
+	// verify that registering these works. The functions actually
+	// available in a real module will be determined dynamically by
+	// Terraform core based on declarations in that module, so here
+	// we're just aiming to test whether dispatching to these works
+	// at all, not to test that any particular functions work.
+	externalFuncs := ExternalFuncs{
+		Provider: map[string]map[string]function.Function{
+			"foo": {
+				"upper": stdlib.UpperFunc,
+			},
+		},
+	}
 
 	t.Run("all functions are tested", func(t *testing.T) {
 		data := &dataForTests{} // no variables available; we only need literals here
 		scope := &Scope{
-			Data:    data,
-			BaseDir: "./testdata/functions-test", // for the functions that read from the filesystem
+			Data:          data,
+			BaseDir:       "./testdata/functions-test", // for the functions that read from the filesystem
+			ExternalFuncs: externalFuncs,
 		}
 
 		// Check that there is at least one test case for each function, omitting
@@ -1207,6 +1276,11 @@ func TestFunctions(t *testing.T) {
 			delete(allFunctions, impureFunc)
 		}
 		for f := range scope.Functions() {
+			if strings.Contains(f, "::") {
+				// Only non-namespaced functions are absolutely required to
+				// have at least one test. (Others _may_ have tests.)
+				continue
+			}
 			if _, ok := tests[f]; !ok {
 				t.Errorf("Missing test for function %s\n", f)
 			}
@@ -1230,8 +1304,9 @@ func TestFunctions(t *testing.T) {
 					t.Run(testName, func(t *testing.T) {
 						data := &dataForTests{} // no variables available; we only need literals here
 						scope := &Scope{
-							Data:    data,
-							BaseDir: "./testdata/functions-test", // for the functions that read from the filesystem
+							Data:          data,
+							BaseDir:       "./testdata/functions-test", // for the functions that read from the filesystem
+							ExternalFuncs: externalFuncs,
 						}
 
 						expr, parseDiags := hclsyntax.ParseExpression([]byte(test.src), "test.hcl", hcl.Pos{Line: 1, Column: 1})
@@ -1262,11 +1337,18 @@ func TestFunctions(t *testing.T) {
 
 			for _, test := range funcTests {
 				t.Run(test.src, func(t *testing.T) {
-					data := &dataForTests{} // no variables available; we only need literals here
+					data := &dataForTests{
+						LocalValues: map[string]cty.Value{
+							"greeting_template": cty.StringVal("Hello, ${name}!"),
+							"ephemeral":         cty.StringVal("ephemeral").Mark(marks.Ephemeral),
+						},
+					}
 					scope := &Scope{
 						Data:          data,
+						ParseRef:      addrs.ParseRef,
 						BaseDir:       "./testdata/functions-test", // for the functions that read from the filesystem
 						PlanTimestamp: time.Date(2004, 04, 25, 15, 00, 00, 000, time.UTC),
+						ExternalFuncs: externalFuncs,
 					}
 					prepareScope(t, scope)
 
@@ -1295,6 +1377,26 @@ func TestFunctions(t *testing.T) {
 	}
 }
 
+func TestPlanTimeStampUnknown(t *testing.T) {
+	// plantimestamp should return an unknown if there is no timestamp, which
+	// happens during validation
+	expr, parseDiags := hclsyntax.ParseExpression([]byte("plantimestamp()"), "test.hcl", hcl.Pos{Line: 1, Column: 1})
+	if parseDiags.HasErrors() {
+		t.Fatal(parseDiags)
+	}
+
+	scope := &Scope{}
+	got, diags := scope.EvalExpr(expr, cty.DynamicPseudoType)
+	if diags.HasErrors() {
+		t.Fatal(diags.Err())
+
+	}
+
+	if got.IsKnown() {
+		t.Fatalf("plantimestamp() should be unknown, got %#v\n", got)
+	}
+}
+
 const (
 	CipherBase64 = "eczGaDhXDbOFRZGhjx2etVzWbRqWDlmq0bvNt284JHVbwCgObiuyX9uV0LSAMY707IEgMkExJqXmsB4OWKxvB7epRB9G/3+F+pcrQpODlDuL9oDUAsa65zEpYF0Wbn7Oh7nrMQncyUPpyr9WUlALl0gRWytOA23S+y5joa4M34KFpawFgoqTu/2EEH4Xl1zo+0fy73fEto+nfkUY+meuyGZ1nUx/+DljP7ZqxHBFSlLODmtuTMdswUbHbXbWneW51D7Jm7xB8nSdiA2JQNK5+Sg5x8aNfgvFTt/m2w2+qpsyFa5Wjeu6fZmXSl840CA07aXbk9vN4I81WmJyblD/ZA=="
 	PrivateKey   = `
