@@ -36,15 +36,15 @@ func testApplyDiff(t *testing.T,
 
 	testSchema := providers.Schema{
 		Version: int64(resource.SchemaVersion),
-		Block:   resourceSchemaToBlock(resource.Schema),
+		Body:    resourceSchemaToBlock(resource.Schema),
 	}
 
-	stateVal, err := StateValueFromInstanceState(state, testSchema.Block.ImpliedType())
+	stateVal, err := StateValueFromInstanceState(state, testSchema.Body.ImpliedType())
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	newState, err := ApplyDiff(stateVal, diff, testSchema.Block)
+	newState, err := ApplyDiff(stateVal, diff, testSchema.Body)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -72,7 +72,7 @@ func testApplyDiff(t *testing.T,
 
 	// Resource.Meta will be hanlded separately, so it's OK that we lose the
 	// timeout values here.
-	expectedState, err := StateValueFromInstanceState(expected, testSchema.Block.ImpliedType())
+	expectedState, err := StateValueFromInstanceState(expected, testSchema.Body.ImpliedType())
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -334,15 +334,15 @@ func TestShimResourceDiff_Timeout_diff(t *testing.T) {
 
 	testSchema := providers.Schema{
 		Version: int64(r.SchemaVersion),
-		Block:   resourceSchemaToBlock(r.Schema),
+		Body:    resourceSchemaToBlock(r.Schema),
 	}
 
-	initialVal, err := StateValueFromInstanceState(createdState, testSchema.Block.ImpliedType())
+	initialVal, err := StateValueFromInstanceState(createdState, testSchema.Body.ImpliedType())
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	appliedVal, err := StateValueFromInstanceState(applied, testSchema.Block.ImpliedType())
+	appliedVal, err := StateValueFromInstanceState(applied, testSchema.Body.ImpliedType())
 	if err != nil {
 		t.Fatal(err)
 	}
