@@ -5,334 +5,10 @@ package terraform
 
 import (
 	"fmt"
-	"reflect"
 	"strconv"
-	"strings"
 	"testing"
-
-	"github.com/hashicorp/terraform/internal/addrs"
 )
 
-func TestDiffEmpty(t *testing.T) {
-	var diff *Diff
-	if !diff.Empty() {
-		t.Fatal("should be empty")
-	}
-
-	diff = new(Diff)
-	if !diff.Empty() {
-		t.Fatal("should be empty")
-	}
-
-	mod := diff.AddModule(addrs.RootModuleInstance)
-	mod.Resources["nodeA"] = &InstanceDiff{
-		Attributes: map[string]*ResourceAttrDiff{
-			"foo": &ResourceAttrDiff{
-				Old: "foo",
-				New: "bar",
-			},
-		},
-	}
-
-	if diff.Empty() {
-		t.Fatal("should not be empty")
-	}
-}
-
-func TestDiffEmpty_taintedIsNotEmpty(t *testing.T) {
-	diff := new(Diff)
-
-	mod := diff.AddModule(addrs.RootModuleInstance)
-	mod.Resources["nodeA"] = &InstanceDiff{
-		DestroyTainted: true,
-	}
-
-	if diff.Empty() {
-		t.Fatal("should not be empty, since DestroyTainted was set")
-	}
-}
-
-func TestDiffEqual(t *testing.T) {
-	cases := map[string]struct {
-		D1, D2 *Diff
-		Equal  bool
-	}{
-		"nil": {
-			nil,
-			new(Diff),
-			false,
-		},
-
-		"empty": {
-			new(Diff),
-			new(Diff),
-			true,
-		},
-
-		"different module order": {
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}},
-					&ModuleDiff{Path: []string{"root", "bar"}},
-				},
-			},
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "bar"}},
-					&ModuleDiff{Path: []string{"root", "foo"}},
-				},
-			},
-			true,
-		},
-
-		"different module diff destroys": {
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}, Destroy: true},
-				},
-			},
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}, Destroy: false},
-				},
-			},
-			true,
-		},
-	}
-
-	for name, tc := range cases {
-		t.Run(name, func(t *testing.T) {
-			actual := tc.D1.Equal(tc.D2)
-			if actual != tc.Equal {
-				t.Fatalf("expected: %v\n\n%#v\n\n%#v", tc.Equal, tc.D1, tc.D2)
-			}
-		})
-	}
-}
-
-func TestDiffPrune(t *testing.T) {
-	cases := map[string]struct {
-		D1, D2 *Diff
-	}{
-		"nil": {
-			nil,
-			nil,
-		},
-
-		"empty": {
-			new(Diff),
-			new(Diff),
-		},
-
-		"empty module": {
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}},
-				},
-			},
-			&Diff{},
-		},
-
-		"destroy module": {
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}, Destroy: true},
-				},
-			},
-			&Diff{
-				Modules: []*ModuleDiff{
-					&ModuleDiff{Path: []string{"root", "foo"}, Destroy: true},
-				},
-			},
-		},
-	}
-
-	for name, tc := range cases {
-		t.Run(name, func(t *testing.T) {
-			tc.D1.Prune()
-			if !tc.D1.Equal(tc.D2) {
-				t.Fatalf("bad:\n\n%#v\n\n%#v", tc.D1, tc.D2)
-			}
-		})
-	}
-}
-
-func TestModuleDiff_ChangeType(t *testing.T) {
-	cases := []struct {
-		Diff   *ModuleDiff
-		Result DiffChangeType
-	}{
-		{
-			&ModuleDiff{},
-			DiffNone,
-		},
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo": &InstanceDiff{Destroy: true},
-				},
-			},
-			DiffDestroy,
-		},
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo": &InstanceDiff{
-						Attributes: map[string]*ResourceAttrDiff{
-							"foo": &ResourceAttrDiff{
-								Old: "",
-								New: "bar",
-							},
-						},
-					},
-				},
-			},
-			DiffUpdate,
-		},
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo": &InstanceDiff{
-						Attributes: map[string]*ResourceAttrDiff{
-							"foo": &ResourceAttrDiff{
-								Old:         "",
-								New:         "bar",
-								RequiresNew: true,
-							},
-						},
-					},
-				},
-			},
-			DiffCreate,
-		},
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo": &InstanceDiff{
-						Destroy: true,
-						Attributes: map[string]*ResourceAttrDiff{
-							"foo": &ResourceAttrDiff{
-								Old:         "",
-								New:         "bar",
-								RequiresNew: true,
-							},
-						},
-					},
-				},
-			},
-			DiffUpdate,
-		},
-	}
-
-	for i, tc := range cases {
-		actual := tc.Diff.ChangeType()
-		if actual != tc.Result {
-			t.Fatalf("%d: %#v", i, actual)
-		}
-	}
-}
-
-func TestDiff_DeepCopy(t *testing.T) {
-	cases := map[string]*Diff{
-		"empty": &Diff{},
-
-		"basic diff": &Diff{
-			Modules: []*ModuleDiff{
-				&ModuleDiff{
-					Path: []string{"root"},
-					Resources: map[string]*InstanceDiff{
-						"aws_instance.foo": &InstanceDiff{
-							Attributes: map[string]*ResourceAttrDiff{
-								"num": &ResourceAttrDiff{
-									Old: "0",
-									New: "2",
-								},
-							},
-						},
-					},
-				},
-			},
-		},
-	}
-
-	for name, tc := range cases {
-		t.Run(name, func(t *testing.T) {
-			dup := tc.DeepCopy()
-			if !reflect.DeepEqual(dup, tc) {
-				t.Fatalf("\n%#v\n\n%#v", dup, tc)
-			}
-		})
-	}
-}
-
-func TestModuleDiff_Empty(t *testing.T) {
-	diff := new(ModuleDiff)
-	if !diff.Empty() {
-		t.Fatal("should be empty")
-	}
-
-	diff.Resources = map[string]*InstanceDiff{
-		"nodeA": &InstanceDiff{},
-	}
-
-	if !diff.Empty() {
-		t.Fatal("should be empty")
-	}
-
-	diff.Resources["nodeA"].Attributes = map[string]*ResourceAttrDiff{
-		"foo": &ResourceAttrDiff{
-			Old: "foo",
-			New: "bar",
-		},
-	}
-
-	if diff.Empty() {
-		t.Fatal("should not be empty")
-	}
-
-	diff.Resources["nodeA"].Attributes = nil
-	diff.Resources["nodeA"].Destroy = true
-
-	if diff.Empty() {
-		t.Fatal("should not be empty")
-	}
-}
-
-func TestModuleDiff_String(t *testing.T) {
-	diff := &ModuleDiff{
-		Resources: map[string]*InstanceDiff{
-			"nodeA": &InstanceDiff{
-				Attributes: map[string]*ResourceAttrDiff{
-					"foo": &ResourceAttrDiff{
-						Old: "foo",
-						New: "bar",
-					},
-					"bar": &ResourceAttrDiff{
-						Old:         "foo",
-						NewComputed: true,
-					},
-					"longfoo": &ResourceAttrDiff{
-						Old:         "foo",
-						New:         "bar",
-						RequiresNew: true,
-					},
-					"secretfoo": &ResourceAttrDiff{
-						Old:       "foo",
-						New:       "bar",
-						Sensitive: true,
-					},
-				},
-			},
-		},
-	}
-
-	actual := strings.TrimSpace(diff.String())
-	expected := strings.TrimSpace(moduleDiffStrBasic)
-	if actual != expected {
-		t.Fatalf("bad:\n%s", actual)
-	}
-}
-
 func TestInstanceDiff_ChangeType(t *testing.T) {
 	cases := []struct {
 		Diff   *InstanceDiff
@@ -437,68 +113,6 @@ func TestInstanceDiff_Empty(t *testing.T) {
 	}
 }
 
-func TestModuleDiff_Instances(t *testing.T) {
-	yesDiff := &InstanceDiff{Destroy: true}
-	noDiff := &InstanceDiff{Destroy: true, DestroyTainted: true}
-
-	cases := []struct {
-		Diff   *ModuleDiff
-		Id     string
-		Result []*InstanceDiff
-	}{
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo": yesDiff,
-					"bar": noDiff,
-				},
-			},
-			"foo",
-			[]*InstanceDiff{
-				yesDiff,
-			},
-		},
-
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo":   yesDiff,
-					"foo.0": yesDiff,
-					"bar":   noDiff,
-				},
-			},
-			"foo",
-			[]*InstanceDiff{
-				yesDiff,
-				yesDiff,
-			},
-		},
-
-		{
-			&ModuleDiff{
-				Resources: map[string]*InstanceDiff{
-					"foo":     yesDiff,
-					"foo.0":   yesDiff,
-					"foo_bar": noDiff,
-					"bar":     noDiff,
-				},
-			},
-			"foo",
-			[]*InstanceDiff{
-				yesDiff,
-				yesDiff,
-			},
-		},
-	}
-
-	for i, tc := range cases {
-		actual := tc.Diff.Instances(tc.Id)
-		if !reflect.DeepEqual(actual, tc.Result) {
-			t.Fatalf("%d: %#v", i, actual)
-		}
-	}
-}
-
 func TestInstanceDiff_RequiresNew(t *testing.T) {
 	rd := &InstanceDiff{
 		Attributes: map[string]*ResourceAttrDiff{
@@ -1210,14 +824,6 @@ func TestInstanceDiffSame(t *testing.T) {
 	}
 }
 
-const moduleDiffStrBasic = `
-CREATE: nodeA
-  bar:       "foo" => "<computed>"
-  foo:       "foo" => "bar"
-  longfoo:   "foo" => "bar" (forces new resource)
-  secretfoo: "<sensitive>" => "<sensitive>" (attribute changed)
-`
-
 func TestCountFlatmapContainerValues(t *testing.T) {
 	for i, tc := range []struct {
 		attrs map[string]string
