@@ -33,6 +33,15 @@ func Provider() providers.Interface {
 				},
 			},
 		},
+		Identity: &configschema.Object{
+			Attributes: map[string]*configschema.Attribute{
+				"id": {
+					Type:     cty.String,
+					Required: true,
+				},
+			},
+			Nesting: configschema.NestingSingle,
+		},
 	}
 
 	return simple{
@@ -46,6 +55,21 @@ func Provider() providers.Interface {
 			DataSources: map[string]providers.Schema{
 				"simple_resource": simpleResource,
 			},
+			EphemeralResourceTypes: map[string]providers.Schema{
+				"simple_resource": simpleResource,
+			},
+			ListResourceTypes: map[string]providers.Schema{
+				"simple_resource": {
+					Body: &configschema.Block{
+						Attributes: map[string]*configschema.Attribute{
+							"value": {
+								Optional: true,
+								Type:     cty.String,
+							},
+						},
+					},
+				},
+			},
 			ServerCapabilities: providers.ServerCapabilities{
 				PlanDestroy: true,
 			},
@@ -88,6 +112,10 @@ func (s simple) ValidateDataResourceConfig(req providers.ValidateDataResourceCon
 	return resp
 }
 
+func (s simple) ValidateListResourceConfig(req providers.ValidateListResourceConfigRequest) (resp providers.ValidateListResourceConfigResponse) {
+	return resp
+}
+
 func (p simple) UpgradeResourceState(req providers.UpgradeResourceStateRequest) (resp providers.UpgradeResourceStateResponse) {
 	ty := p.schema.ResourceTypes[req.TypeName].Body.ImpliedType()
 	val, err := ctyjson.Unmarshal(req.RawStateJSON, ty)
@@ -204,6 +232,54 @@ func (s simple) CallFunction(req providers.CallFunctionRequest) (resp providers.
 	panic("CallFunction on provider that didn't declare any functions")
 }
 
+func (s simple) ListResource(req providers.ListResourceRequest) (resp providers.ListResourceResponse) {
+	vals := make([]cty.Value, 0)
+
+	staticVal := cty.StringVal("static_value")
+	m := req.Config.AsValueMap()
+	if val, ok := m["value"]; ok && val != cty.NilVal {
+		staticVal = val
+	}
+
+	obj := map[string]cty.Value{
+		"display_name": cty.StringVal("static_display_name"),
+		"identity": cty.ObjectVal(map[string]cty.Value{
+			"id": cty.StringVal("static_id"),
+		}),
+	}
+	if req.IncludeResourceObject {
+		obj["state"] = cty.ObjectVal(map[string]cty.Value{
+			"id":    cty.StringVal("static_id"),
+			"value": staticVal,
+		})
+	}
+	vals = append(vals, cty.ObjectVal(obj))
+
+	resp.Result = cty.ObjectVal(map[string]cty.Value{
+		"data":   cty.TupleVal(vals),
+		"config": req.Config,
+	})
+	return
+}
+
+func (s simple) ValidateStateStoreConfig(req providers.ValidateStateStoreConfigRequest) providers.ValidateStateStoreConfigResponse {
+	panic("not implemented")
+}
+
+func (s simple) ConfigureStateStore(req providers.ConfigureStateStoreRequest) providers.ConfigureStateStoreResponse {
+	panic("not implemented")
+}
+
+func (s simple) GetStates(req providers.GetStatesRequest) providers.GetStatesResponse {
+	// provider-simple uses protocol version 5, which does not include the RPC that maps to this method
+	panic("not implemented")
+}
+
+func (s simple) DeleteState(req providers.DeleteStateRequest) providers.DeleteStateResponse {
+	// provider-simple uses protocol version 5, which does not include the RPC that maps to this method
+	panic("not implemented")
+}
+
 func (s simple) Close() error {
 	return nil
 }
