@@ -50,6 +50,11 @@ type MockProvider struct {
 	ValidateDataResourceConfigRequest  providers.ValidateDataResourceConfigRequest
 	ValidateDataResourceConfigFn       func(providers.ValidateDataResourceConfigRequest) providers.ValidateDataResourceConfigResponse
 
+	ValidateListResourceConfigCalled   bool
+	ValidateListResourceConfigResponse *providers.ValidateListResourceConfigResponse
+	ValidateListResourceConfigRequest  providers.ValidateListResourceConfigRequest
+	ValidateListResourceConfigFn       func(providers.ValidateListResourceConfigRequest) providers.ValidateListResourceConfigResponse
+
 	UpgradeResourceStateCalled   bool
 	UpgradeResourceStateResponse *providers.UpgradeResourceStateResponse
 	UpgradeResourceStateRequest  providers.UpgradeResourceStateRequest
@@ -121,13 +126,37 @@ type MockProvider struct {
 	CallFunctionRequest  providers.CallFunctionRequest
 	CallFunctionFn       func(providers.CallFunctionRequest) providers.CallFunctionResponse
 
+	ListResourceCalled   bool
+	ListResourceResponse providers.ListResourceResponse
+	ListResourceRequest  providers.ListResourceRequest
+	ListResourceFn       func(providers.ListResourceRequest) providers.ListResourceResponse
+
+	ValidateStateStoreConfigCalled   bool
+	ValidateStateStoreConfigResponse *providers.ValidateStateStoreConfigResponse
+	ValidateStateStoreConfigRequest  providers.ValidateStateStoreConfigRequest
+	ValidateStateStoreConfigFn       func(providers.ValidateStateStoreConfigRequest) providers.ValidateStateStoreConfigResponse
+
+	ConfigureStateStoreCalled   bool
+	ConfigureStateStoreResponse *providers.ConfigureStateStoreResponse
+	ConfigureStateStoreRequest  providers.ConfigureStateStoreRequest
+	ConfigureStateStoreFn       func(providers.ConfigureStateStoreRequest) providers.ConfigureStateStoreResponse
+
+	GetStatesCalled   bool
+	GetStatesResponse *providers.GetStatesResponse
+	GetStatesRequest  providers.GetStatesRequest
+	GetStatesFn       func(providers.GetStatesRequest) providers.GetStatesResponse
+
+	DeleteStateCalled   bool
+	DeleteStateResponse *providers.DeleteStateResponse
+	DeleteStateRequest  providers.DeleteStateRequest
+	DeleteStateFn       func(providers.DeleteStateRequest) providers.DeleteStateResponse
+
 	CloseCalled bool
 	CloseError  error
 }
 
 func (p *MockProvider) GetProviderSchema() providers.GetProviderSchemaResponse {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 	p.GetProviderSchemaCalled = true
 	return p.getProviderSchema()
 }
@@ -141,15 +170,16 @@ func (p *MockProvider) getProviderSchema() providers.GetProviderSchemaResponse {
 	}
 
 	return providers.GetProviderSchemaResponse{
-		Provider:      providers.Schema{},
-		DataSources:   map[string]providers.Schema{},
-		ResourceTypes: map[string]providers.Schema{},
+		Provider:          providers.Schema{},
+		DataSources:       map[string]providers.Schema{},
+		ResourceTypes:     map[string]providers.Schema{},
+		ListResourceTypes: map[string]providers.Schema{},
+		StateStores:       map[string]providers.Schema{},
 	}
 }
 
 func (p *MockProvider) GetResourceIdentitySchemas() providers.GetResourceIdentitySchemasResponse {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 	p.GetResourceIdentitySchemasCalled = true
 
 	return p.getResourceIdentitySchemas()
@@ -160,14 +190,25 @@ func (p *MockProvider) getResourceIdentitySchemas() providers.GetResourceIdentit
 		return *p.GetResourceIdentitySchemasResponse
 	}
 
-	return providers.GetResourceIdentitySchemasResponse{
-		IdentityTypes: map[string]providers.IdentitySchema{},
+	resp := providers.GetResourceIdentitySchemasResponse{IdentityTypes: make(map[string]providers.IdentitySchema)}
+	if p.GetProviderSchemaResponse != nil {
+
+		for typeName, schema := range p.GetProviderSchemaResponse.ResourceTypes {
+			if schema.Identity != nil {
+				resp.IdentityTypes[typeName] = providers.IdentitySchema{
+					Version: schema.IdentityVersion,
+					Body:    schema.Identity,
+				}
+			}
+		}
+
 	}
+
+	return resp
 }
 
 func (p *MockProvider) ValidateProviderConfig(r providers.ValidateProviderConfigRequest) (resp providers.ValidateProviderConfigResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ValidateProviderConfigCalled = true
 	p.ValidateProviderConfigRequest = r
@@ -184,8 +225,7 @@ func (p *MockProvider) ValidateProviderConfig(r providers.ValidateProviderConfig
 }
 
 func (p *MockProvider) ValidateResourceConfig(r providers.ValidateResourceConfigRequest) (resp providers.ValidateResourceConfigResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ValidateResourceConfigCalled = true
 	p.ValidateResourceConfigRequest = r
@@ -216,8 +256,7 @@ func (p *MockProvider) ValidateResourceConfig(r providers.ValidateResourceConfig
 }
 
 func (p *MockProvider) ValidateDataResourceConfig(r providers.ValidateDataResourceConfigRequest) (resp providers.ValidateDataResourceConfigResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ValidateDataResourceConfigCalled = true
 	p.ValidateDataResourceConfigRequest = r
@@ -246,43 +285,70 @@ func (p *MockProvider) ValidateDataResourceConfig(r providers.ValidateDataResour
 }
 
 func (p *MockProvider) ValidateEphemeralResourceConfig(r providers.ValidateEphemeralResourceConfigRequest) (resp providers.ValidateEphemeralResourceConfigResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ValidateEphemeralResourceConfigCalled = true
 	p.ValidateEphemeralResourceConfigRequest = r
 
 	// Marshall the value to replicate behavior by the GRPC protocol
-	dataSchema, ok := p.getProviderSchema().EphemeralResourceTypes[r.TypeName]
+	ephemeralSchema, ok := p.getProviderSchema().EphemeralResourceTypes[r.TypeName]
 	if !ok {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("no schema found for %q", r.TypeName))
 		return resp
 	}
-	_, err := msgpack.Marshal(r.Config, dataSchema.Body.ImpliedType())
+	_, err := msgpack.Marshal(r.Config, ephemeralSchema.Body.ImpliedType())
 	if err != nil {
 		resp.Diagnostics = resp.Diagnostics.Append(err)
 		return resp
 	}
 
-	if p.ValidateDataResourceConfigFn != nil {
+	if p.ValidateEphemeralResourceConfigFn != nil {
 		return p.ValidateEphemeralResourceConfigFn(r)
 	}
 
-	if p.ValidateDataResourceConfigResponse != nil {
+	if p.ValidateEphemeralResourceConfigResponse != nil {
 		return *p.ValidateEphemeralResourceConfigResponse
 	}
 
 	return resp
 }
 
+func (p *MockProvider) ValidateListResourceConfig(r providers.ValidateListResourceConfigRequest) (resp providers.ValidateListResourceConfigResponse) {
+	defer p.beginWrite()()
+
+	p.ValidateListResourceConfigCalled = true
+	p.ValidateListResourceConfigRequest = r
+
+	// Marshall the value to replicate behavior by the GRPC protocol
+	listSchema, ok := p.getProviderSchema().ListResourceTypes[r.TypeName]
+	if !ok {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("no schema found for %q", r.TypeName))
+		return resp
+	}
+	_, err := msgpack.Marshal(r.Config, listSchema.Body.ImpliedType())
+	if err != nil {
+		resp.Diagnostics = resp.Diagnostics.Append(err)
+		return resp
+	}
+
+	if p.ValidateListResourceConfigFn != nil {
+		return p.ValidateListResourceConfigFn(r)
+	}
+
+	if p.ValidateListResourceConfigResponse != nil {
+		return *p.ValidateListResourceConfigResponse
+	}
+
+	return resp
+}
+
 // UpgradeResourceState mocks out the response from the provider during an UpgradeResourceState RPC
 // The default logic will return the resource's state unchanged, unless other logic is defined on the mock (e.g. UpgradeResourceStateFn)
 //
 // When using this mock you may need to provide custom logic if the plugin-framework alters values in state,
 // e.g. when handling write-only attributes.
 func (p *MockProvider) UpgradeResourceState(r providers.UpgradeResourceStateRequest) (resp providers.UpgradeResourceStateResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before UpgradeResourceState %q", r.TypeName))
@@ -330,8 +396,7 @@ func (p *MockProvider) UpgradeResourceState(r providers.UpgradeResourceStateRequ
 }
 
 func (p *MockProvider) UpgradeResourceIdentity(r providers.UpgradeResourceIdentityRequest) (resp providers.UpgradeResourceIdentityResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before UpgradeResourceIdentity %q", r.TypeName))
@@ -369,8 +434,7 @@ func (p *MockProvider) UpgradeResourceIdentity(r providers.UpgradeResourceIdenti
 }
 
 func (p *MockProvider) ConfigureProvider(r providers.ConfigureProviderRequest) (resp providers.ConfigureProviderResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ConfigureProviderCalled = true
 	p.ConfigureProviderRequest = r
@@ -401,8 +465,7 @@ func (p *MockProvider) Stop() error {
 }
 
 func (p *MockProvider) ReadResource(r providers.ReadResourceRequest) (resp providers.ReadResourceResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ReadResourceCalled = true
 	p.ReadResourceRequest = r
@@ -477,8 +540,7 @@ func (p *MockProvider) ReadResource(r providers.ReadResourceRequest) (resp provi
 }
 
 func (p *MockProvider) PlanResourceChange(r providers.PlanResourceChangeRequest) (resp providers.PlanResourceChangeResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before PlanResourceChange %q", r.TypeName))
@@ -567,8 +629,7 @@ func (p *MockProvider) PlanResourceChange(r providers.PlanResourceChangeRequest)
 }
 
 func (p *MockProvider) ApplyResourceChange(r providers.ApplyResourceChangeRequest) (resp providers.ApplyResourceChangeResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.ApplyResourceChangeCalled = true
 	p.ApplyResourceChangeRequest = r
@@ -625,8 +686,7 @@ func (p *MockProvider) ApplyResourceChange(r providers.ApplyResourceChangeReques
 }
 
 func (p *MockProvider) ImportResourceState(r providers.ImportResourceStateRequest) (resp providers.ImportResourceStateResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before ImportResourceState %q", r.TypeName))
@@ -670,8 +730,7 @@ func (p *MockProvider) ImportResourceState(r providers.ImportResourceStateReques
 }
 
 func (p *MockProvider) MoveResourceState(r providers.MoveResourceStateRequest) (resp providers.MoveResourceStateResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.MoveResourceStateCalled = true
 	p.MoveResourceStateRequest = r
@@ -687,8 +746,7 @@ func (p *MockProvider) MoveResourceState(r providers.MoveResourceStateRequest) (
 }
 
 func (p *MockProvider) ReadDataSource(r providers.ReadDataSourceRequest) (resp providers.ReadDataSourceResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before ReadDataSource %q", r.TypeName))
@@ -710,8 +768,7 @@ func (p *MockProvider) ReadDataSource(r providers.ReadDataSourceRequest) (resp p
 }
 
 func (p *MockProvider) OpenEphemeralResource(r providers.OpenEphemeralResourceRequest) (resp providers.OpenEphemeralResourceResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before OpenEphemeralResource %q", r.TypeName))
@@ -733,8 +790,7 @@ func (p *MockProvider) OpenEphemeralResource(r providers.OpenEphemeralResourceRe
 }
 
 func (p *MockProvider) RenewEphemeralResource(r providers.RenewEphemeralResourceRequest) (resp providers.RenewEphemeralResourceResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before RenewEphemeralResource %q", r.TypeName))
@@ -756,8 +812,7 @@ func (p *MockProvider) RenewEphemeralResource(r providers.RenewEphemeralResource
 }
 
 func (p *MockProvider) CloseEphemeralResource(r providers.CloseEphemeralResourceRequest) (resp providers.CloseEphemeralResourceResponse) {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	if !p.ConfigureProviderCalled {
 		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before CloseEphemeralResource %q", r.TypeName))
@@ -779,8 +834,7 @@ func (p *MockProvider) CloseEphemeralResource(r providers.CloseEphemeralResource
 }
 
 func (p *MockProvider) CallFunction(r providers.CallFunctionRequest) providers.CallFunctionResponse {
-	p.Lock()
-	defer p.Unlock()
+	defer p.beginWrite()()
 
 	p.CallFunctionCalled = true
 	p.CallFunctionRequest = r
@@ -792,10 +846,166 @@ func (p *MockProvider) CallFunction(r providers.CallFunctionRequest) providers.C
 	return p.CallFunctionResponse
 }
 
-func (p *MockProvider) Close() error {
+func (p *MockProvider) ListResource(r providers.ListResourceRequest) providers.ListResourceResponse {
 	p.Lock()
 	defer p.Unlock()
+	p.ListResourceCalled = true
+	p.ListResourceRequest = r
+
+	if p.ListResourceFn != nil {
+		return p.ListResourceFn(r)
+	}
+
+	return p.ListResourceResponse
+}
+
+func (p *MockProvider) ValidateStateStoreConfig(r providers.ValidateStateStoreConfigRequest) (resp providers.ValidateStateStoreConfigResponse) {
+	p.Lock()
+	defer p.Unlock()
+
+	p.ValidateStateStoreConfigCalled = true
+	p.ValidateStateStoreConfigRequest = r
+
+	if !p.ConfigureProviderCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before ValidateStateStoreConfig %q", r.TypeName))
+		return resp
+	}
+
+	// Marshall the value to replicate behavior by the GRPC protocol,
+	// and return any relevant errors
+	storeSchema, ok := p.getProviderSchema().StateStores[r.TypeName]
+	if !ok {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("no schema found for state store %q", r.TypeName))
+		return resp
+	}
+
+	if p.ValidateStateStoreConfigResponse != nil {
+		return *p.ValidateStateStoreConfigResponse
+	}
+
+	_, err := msgpack.Marshal(r.Config, storeSchema.Body.ImpliedType())
+	if err != nil {
+		resp.Diagnostics = resp.Diagnostics.Append(err)
+		return resp
+	}
+
+	if p.ValidateStateStoreConfigFn != nil {
+		return p.ValidateStateStoreConfigFn(r)
+	}
+
+	return resp
+}
+
+func (p *MockProvider) ConfigureStateStore(r providers.ConfigureStateStoreRequest) (resp providers.ConfigureStateStoreResponse) {
+	p.Lock()
+	defer p.Unlock()
+
+	p.ConfigureStateStoreCalled = true
+	p.ConfigureStateStoreRequest = r
+
+	if !p.ConfigureProviderCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("Configure not called before ConfigureStateStore %q", r.TypeName))
+		return resp
+	}
+
+	// Marshall the value to replicate behavior by the GRPC protocol,
+	// and return any relevant errors
+	storeSchema, ok := p.getProviderSchema().StateStores[r.TypeName]
+	if !ok {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("no schema found for state store %q", r.TypeName))
+		return resp
+	}
+
+	if p.ConfigureStateStoreResponse != nil {
+		return *p.ConfigureStateStoreResponse
+	}
+
+	_, err := msgpack.Marshal(r.Config, storeSchema.Body.ImpliedType())
+	if err != nil {
+		resp.Diagnostics = resp.Diagnostics.Append(err)
+		return resp
+	}
+
+	if p.ConfigureStateStoreFn != nil {
+		return p.ConfigureStateStoreFn(r)
+	}
+
+	return resp
+}
+
+func (p *MockProvider) GetStates(r providers.GetStatesRequest) (resp providers.GetStatesResponse) {
+	p.Lock()
+	defer p.Unlock()
+
+	p.GetStatesCalled = true
+	p.GetStatesRequest = r
+
+	if !p.ConfigureProviderCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("ConfigureProvider not called before GetStates %q", r.TypeName))
+	}
+	if !p.ConfigureStateStoreCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("ConfigureStateStore not called before GetStates %q", r.TypeName))
+	}
+	if resp.Diagnostics.HasErrors() {
+		return resp
+	}
+
+	if p.GetStatesResponse != nil {
+		return *p.GetStatesResponse
+	}
+
+	if p.GetStatesFn != nil {
+		return p.GetStatesFn(r)
+	}
+
+	// If the mock has no further inputs, return an empty list.
+	// The state store should be reporting a minimum of the default workspace usually,
+	// but this should be achieved by querying data storage and identifying the artifact
+	// for that workspace, and reporting that the workspace exists.
+	resp.States = []string{}
+
+	return resp
+}
+
+func (p *MockProvider) DeleteState(r providers.DeleteStateRequest) (resp providers.DeleteStateResponse) {
+	p.Lock()
+	defer p.Unlock()
+
+	p.DeleteStateCalled = true
+	p.DeleteStateRequest = r
+
+	if !p.ConfigureProviderCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("ConfigureProvider not called before DeleteState %q", r.TypeName))
+	}
+	if !p.ConfigureStateStoreCalled {
+		resp.Diagnostics = resp.Diagnostics.Append(fmt.Errorf("ConfigureStateStore not called before DeleteState %q", r.TypeName))
+	}
+	if resp.Diagnostics.HasErrors() {
+		return resp
+	}
+
+	if p.DeleteStateResponse != nil {
+		return *p.DeleteStateResponse
+	}
+
+	if p.DeleteStateFn != nil {
+		return p.DeleteStateFn(r)
+	}
+
+	// There's no logic we can include here in the absence of other fields on the mock.
+
+	// If the response contains no diagnostics then the deletion is assumed to be successful.
+	return resp
+}
+
+func (p *MockProvider) Close() error {
+	defer p.beginWrite()()
 
 	p.CloseCalled = true
 	return p.CloseError
 }
+
+func (p *MockProvider) beginWrite() func() {
+	p.Lock()
+	return p.Unlock
+}
