@@ -10,7 +10,9 @@ import (
 	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/dag"
 	"github.com/hashicorp/terraform/internal/logging"
+	"github.com/hashicorp/terraform/internal/providers"
 	"github.com/hashicorp/terraform/internal/states"
+	"github.com/hashicorp/terraform/internal/tfdiags"
 )
 
 // ApplyMoves modifies in-place the given state object so that any existing
@@ -28,11 +30,11 @@ import (
 //
 // ApplyMoves expects exclusive access to the given state while it's running.
 // Don't read or write any part of the state structure until ApplyMoves returns.
-func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
+func ApplyMoves(stmts []MoveStatement, state *states.State, providerFactory map[addrs.Provider]providers.Factory) (MoveResults, tfdiags.Diagnostics) {
 	ret := makeMoveResults()
 
 	if len(stmts) == 0 {
-		return ret
+		return ret, nil
 	}
 
 	// The methodology here is to construct a small graph of all of the move
@@ -47,7 +49,7 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 	// separate validation step should detect this and return an error.
 	if diags := validateMoveStatementGraph(g); diags.HasErrors() {
 		log.Printf("[ERROR] ApplyMoves: %s", diags.ErrWithWarnings())
-		return ret
+		return ret, nil
 	}
 
 	// The graph must be reduced in order for ReverseDepthFirstWalk to work
@@ -65,7 +67,7 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 
 	if startNodes.Len() == 0 {
 		log.Println("[TRACE] refactoring.ApplyMoves: No 'moved' statements to consider in this configuration")
-		return ret
+		return ret, nil
 	}
 
 	log.Printf("[TRACE] refactoring.ApplyMoves: Processing 'moved' statements in the configuration\n%s", logging.Indent(g.String()))
@@ -90,6 +92,15 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 		})
 	}
 
+	crossTypeMover := &crossTypeMover{
+		State:             state,
+		ProviderFactories: providerFactory,
+		ProviderCache:     make(map[addrs.Provider]providers.Interface),
+	}
+
+	var diags tfdiags.Diagnostics
+
+	syncState := state.SyncWrapper()
 	for _, v := range g.ReverseTopologicalOrder() {
 		stmt := v.(*MoveStatement)
 
@@ -125,7 +136,7 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 						}
 					}
 
-					state.MoveModuleInstance(modAddr, newAddr)
+					syncState.MoveModuleInstance(modAddr, newAddr)
 					continue
 				}
 			case addrs.MoveEndpointResource:
@@ -152,9 +163,12 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 							continue
 						}
 
+						crossTypeMove, prepareDiags := crossTypeMover.prepareCrossTypeMove(stmt, rAddr, newAddr)
+						diags = diags.Append(prepareDiags)
 						for key := range rs.Instances {
 							oldInst := rAddr.Instance(key)
 							newInst := newAddr.Instance(key)
+							diags = diags.Append(crossTypeMove.applyCrossTypeMove(stmt, oldInst, newInst, syncState))
 							recordOldAddr(oldInst, newInst)
 						}
 						state.MoveAbsResource(rAddr, newAddr)
@@ -174,9 +188,11 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 								continue
 							}
 
+							crossTypeMove, crossTypeMoveDiags := crossTypeMover.prepareCrossTypeMove(stmt, iAddr.ContainingResource(), newAddr.ContainingResource())
+							diags = diags.Append(crossTypeMoveDiags)
+							diags = diags.Append(crossTypeMove.applyCrossTypeMove(stmt, iAddr, newAddr, syncState))
 							recordOldAddr(iAddr, newAddr)
-
-							state.MoveAbsResourceInstance(iAddr, newAddr)
+							syncState.MoveResourceInstance(iAddr, newAddr)
 							continue
 						}
 					}
@@ -186,8 +202,10 @@ func ApplyMoves(stmts []MoveStatement, state *states.State) MoveResults {
 			}
 		}
 	}
+	syncState.Close()
 
-	return ret
+	diags = diags.Append(crossTypeMover.close())
+	return ret, diags
 }
 
 // buildMoveStatementGraph constructs a dependency graph of the given move
