@@ -9,6 +9,8 @@ import (
 	"github.com/hashicorp/hcl/v2"
 
 	"github.com/hashicorp/terraform/internal/addrs"
+	"github.com/hashicorp/terraform/internal/collections"
+	"github.com/hashicorp/terraform/internal/stacks/stackaddrs"
 	"github.com/hashicorp/terraform/internal/tfdiags"
 )
 
@@ -45,20 +47,25 @@ type Declarations struct {
 	// overall tree might have their own provider configurations.
 	ProviderConfigs map[addrs.LocalProviderConfig]*ProviderConfig
 
-	// Removed are the list of components that have been removed from the
-	// configuration.
-	Removed map[string][]*Removed
+	// RemovedComponents is the list of components that have been removed from
+	// the configuration.
+	RemovedComponents collections.Map[stackaddrs.ConfigComponent, []*Removed]
+
+	// RemovedEmbeddedStacks is the list of embedded stacks that have been removed
+	// from the configuration.
+	RemovedEmbeddedStacks collections.Map[stackaddrs.ConfigStackCall, []*Removed]
 }
 
 func makeDeclarations() Declarations {
 	return Declarations{
-		EmbeddedStacks:  make(map[string]*EmbeddedStack),
-		Components:      make(map[string]*Component),
-		InputVariables:  make(map[string]*InputVariable),
-		LocalValues:     make(map[string]*LocalValue),
-		OutputValues:    make(map[string]*OutputValue),
-		ProviderConfigs: make(map[addrs.LocalProviderConfig]*ProviderConfig),
-		Removed:         make(map[string][]*Removed),
+		EmbeddedStacks:        make(map[string]*EmbeddedStack),
+		Components:            make(map[string]*Component),
+		InputVariables:        make(map[string]*InputVariable),
+		LocalValues:           make(map[string]*LocalValue),
+		OutputValues:          make(map[string]*OutputValue),
+		ProviderConfigs:       make(map[addrs.LocalProviderConfig]*ProviderConfig),
+		RemovedComponents:     collections.NewMap[stackaddrs.ConfigComponent, []*Removed](),
+		RemovedEmbeddedStacks: collections.NewMap[stackaddrs.ConfigStackCall, []*Removed](),
 	}
 }
 
@@ -82,9 +89,14 @@ func (d *Declarations) addComponent(decl *Component) tfdiags.Diagnostics {
 		return diags
 	}
 
-	if blocks, exists := d.Removed[name]; exists {
+	if blocks, exists := d.RemovedComponents.GetOk(stackaddrs.ConfigComponent{
+		Stack: nil,
+		Item: stackaddrs.Component{
+			Name: name,
+		},
+	}); exists {
 		for _, removed := range blocks {
-			if removed.FromIndex == nil {
+			if removed.From.Component.Index == nil {
 				// If a component has been removed, we should not also find it
 				// in the configuration.
 				//
@@ -130,6 +142,28 @@ func (d *Declarations) addEmbeddedStack(decl *EmbeddedStack) tfdiags.Diagnostics
 		return diags
 	}
 
+	if blocks, exists := d.RemovedEmbeddedStacks.GetOk(stackaddrs.ConfigStackCall{
+		Stack: nil,
+		Item: stackaddrs.StackCall{
+			Name: name,
+		},
+	}); exists {
+		for _, removed := range blocks {
+			if removed.From.Stack[0].Index == nil {
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Stack exists for removed block",
+					Detail: fmt.Sprintf(
+						"A removed block for stack %q was declared without an index, but a stack block with the same name was declared at %s.\n\nA removed block without an index indicates that the stack and all instances were removed from the configuration, and this is not the case.",
+						name, decl.DeclRange.ToHCL(),
+					),
+					Subject: removed.DeclRange.ToHCL().Ptr(),
+				})
+				return diags
+			}
+		}
+	}
+
 	d.EmbeddedStacks[name] = decl
 	return diags
 }
@@ -257,34 +291,60 @@ func (d *Declarations) addRemoved(decl *Removed) tfdiags.Diagnostics {
 	if decl == nil {
 		return diags
 	}
-	name := decl.FromComponent.Name
 
-	if decl.FromIndex == nil {
-		// If the removed block does not have an index, then we shouldn't also
-		// have a component block with the same name. A removed block without
-		// an index indicates that the component and all instances were removed
-		// from the configuration.
-		//
-		// Note that a removed block with an index is allowed to coexist with a
-		// component block with the same name, because it indicates that only
-		// a specific instance was removed and not the whole thing. During the
-		// validate and planning stages we will validate that the clashing
-		// component and removed blocks are not both pointing to the same index.
-		if component, exists := d.Components[name]; exists {
-			diags = diags.Append(&hcl.Diagnostic{
-				Severity: hcl.DiagError,
-				Summary:  "Component exists for removed block",
-				Detail: fmt.Sprintf(
-					"A removed block for component %q was declared without an index, but a component block with the same name was declared at %s.\n\nA removed block without an index indicates that the component and all instances were removed from the configuration, and this is not the case.",
-					name, component.DeclRange.ToHCL(),
-				),
-				Subject: decl.DeclRange.ToHCL().Ptr(),
-			})
-			return diags
+	if decl.From.Component != nil {
+		addr := decl.From.TargetConfigComponent()
+
+		if decl.From.Component.Index == nil && len(decl.From.Stack) == 0 {
+			// If the removed block does not have an index, then we shouldn't also
+			// have a component block with the same name. A removed block without
+			// an index indicates that the component and all instances were removed
+			// from the configuration.
+			//
+			// Note that a removed block with an index is allowed to coexist with a
+			// component block with the same name, because it indicates that only
+			// a specific instance was removed and not the whole thing. During the
+			// validate and planning stages we will validate that the clashing
+			// component and removed blocks are not both pointing to the same index.
+			if component, exists := d.Components[decl.From.Component.Name]; exists {
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Component exists for removed block",
+					Detail: fmt.Sprintf(
+						"A removed block for component %q was declared without an index, but a component block with the same name was declared at %s.\n\nA removed block without an index indicates that the component and all instances were removed from the configuration, and this is not the case.",
+						decl.From.Component.Name, component.DeclRange.ToHCL(),
+					),
+					Subject: decl.DeclRange.ToHCL().Ptr(),
+				})
+				return diags
+			}
 		}
+
+		d.RemovedComponents.Put(addr, append(d.RemovedComponents.Get(addr), decl))
+	} else {
+		addr := decl.From.TargetStack().ToStackCall()
+
+		if len(decl.From.Stack) == 1 && decl.From.Stack[0].Index == nil {
+			// Same logic as for components, we can just error a bit earlier
+			// here if the user is targeting a stack that definitely exists
+			// in the configuration.
+			if stack, exists := d.EmbeddedStacks[decl.From.Stack[0].Name]; exists {
+				diags = diags.Append(&hcl.Diagnostic{
+					Severity: hcl.DiagError,
+					Summary:  "Stack exists for removed block",
+					Detail: fmt.Sprintf(
+						"A removed block for stack %q was declared without an index, but a stack block with the same name was declared at %s.\n\nA removed block without an index indicates that the stack and all instances were removed from the configuration, and this is not the case.",
+						decl.From.Component.Name, stack.DeclRange.ToHCL(),
+					),
+					Subject: decl.DeclRange.ToHCL().Ptr(),
+				})
+				return diags
+			}
+		}
+
+		d.RemovedEmbeddedStacks.Put(addr, append(d.RemovedEmbeddedStacks.Get(addr), decl))
 	}
 
-	d.Removed[name] = append(d.Removed[name], decl)
 	return diags
 }
 
@@ -295,6 +355,11 @@ func (d *Declarations) merge(other *Declarations) tfdiags.Diagnostics {
 			d.addEmbeddedStack(decl),
 		)
 	}
+	for _, blocks := range other.RemovedEmbeddedStacks.All() {
+		for _, decl := range blocks {
+			diags = diags.Append(d.addRemoved(decl))
+		}
+	}
 	for _, decl := range other.Components {
 		diags = diags.Append(
 			d.addComponent(decl),
@@ -323,7 +388,7 @@ func (d *Declarations) merge(other *Declarations) tfdiags.Diagnostics {
 			d.addProviderConfig(decl),
 		)
 	}
-	for _, blocks := range other.Removed {
+	for _, blocks := range other.RemovedComponents.All() {
 		for _, decl := range blocks {
 			diags = diags.Append(
 				d.addRemoved(decl),
