@@ -398,6 +398,6 @@ func (ev *forEachEvaluator) validateResource(forEachVal cty.Value) tfdiags.Diagn
 
 // markSafeLengthInt allows calling LengthInt on marked values safely
 func markSafeLengthInt(val cty.Value) int {
-	v, _ := val.UnmarkDeep()
+	v, _ := val.Unmark()
 	return v.LengthInt()
 }
