@@ -142,12 +142,40 @@ type MockHook struct {
 	PostEphemeralOpReturn      HookAction
 	PostEphemeralOpReturnError error
 
+	PreListQueryCalled      bool
+	PreListQueryAddr        addrs.AbsResourceInstance
+	PreListQueryReturn      HookAction
+	PreListQueryReturnError error
+
+	PostListQueryCalled      bool
+	PostListQueryAddr        addrs.AbsResourceInstance
+	PostListQueryReturn      HookAction
+	PostListQueryReturnError error
+
 	StoppingCalled bool
 
 	PostStateUpdateCalled bool
 	PostStateUpdateState  *states.State
 	PostStateUpdateReturn HookAction
 	PostStateUpdateError  error
+
+	// Fields for StartAction, ProgressAction, CompleteAction
+	StartActionCalled bool
+	StartActionID     HookActionIdentity
+	StartActionReturn HookAction
+	StartActionError  error
+
+	ProgressActionCalled   bool
+	ProgressActionID       HookActionIdentity
+	ProgressActionProgress string
+	ProgressActionReturn   HookAction
+	ProgressActionError    error
+
+	CompleteActionCalled   bool
+	CompleteActionID       HookActionIdentity
+	CompleteActionErrorArg error
+	CompleteActionReturn   HookAction
+	CompleteActionError    error
 }
 
 var _ Hook = (*MockHook)(nil)
@@ -346,6 +374,24 @@ func (h *MockHook) PostEphemeralOp(id HookResourceIdentity, action plans.Action,
 	return h.PostEphemeralOpReturn, h.PostEphemeralOpReturnError
 }
 
+func (h *MockHook) PreListQuery(id HookResourceIdentity, input_config cty.Value) (HookAction, error) {
+	h.Lock()
+	defer h.Unlock()
+
+	h.PreListQueryCalled = true
+	h.PreListQueryAddr = id.Addr
+	return h.PreListQueryReturn, h.PreListQueryReturnError
+}
+
+func (h *MockHook) PostListQuery(id HookResourceIdentity, results plans.QueryResults) (HookAction, error) {
+	h.Lock()
+	defer h.Unlock()
+
+	h.PostListQueryCalled = true
+	h.PostListQueryAddr = id.Addr
+	return h.PostListQueryReturn, h.PostListQueryReturnError
+}
+
 func (h *MockHook) Stopping() {
 	h.Lock()
 	defer h.Unlock()
@@ -361,3 +407,32 @@ func (h *MockHook) PostStateUpdate(new *states.State) (HookAction, error) {
 	h.PostStateUpdateState = new
 	return h.PostStateUpdateReturn, h.PostStateUpdateError
 }
+
+func (h *MockHook) StartAction(id HookActionIdentity) (HookAction, error) {
+	h.Lock()
+	defer h.Unlock()
+
+	h.StartActionCalled = true
+	h.StartActionID = id
+	return h.StartActionReturn, h.StartActionError
+}
+
+func (h *MockHook) ProgressAction(id HookActionIdentity, progress string) (HookAction, error) {
+	h.Lock()
+	defer h.Unlock()
+
+	h.ProgressActionCalled = true
+	h.ProgressActionID = id
+	h.ProgressActionProgress = progress
+	return h.ProgressActionReturn, h.ProgressActionError
+}
+
+func (h *MockHook) CompleteAction(id HookActionIdentity, err error) (HookAction, error) {
+	h.Lock()
+	defer h.Unlock()
+
+	h.CompleteActionCalled = true
+	h.CompleteActionID = id
+	h.CompleteActionErrorArg = err
+	return h.CompleteActionReturn, h.CompleteActionError
+}
