@@ -98,12 +98,32 @@ func (h *stopHook) PostEphemeralOp(id HookResourceIdentity, action plans.Action,
 	return h.hook()
 }
 
+func (h *stopHook) PreListQuery(id HookResourceIdentity, input_config cty.Value) (HookAction, error) {
+	return h.hook()
+}
+
+func (h *stopHook) PostListQuery(id HookResourceIdentity, results plans.QueryResults) (HookAction, error) {
+	return h.hook()
+}
+
 func (h *stopHook) Stopping() {}
 
 func (h *stopHook) PostStateUpdate(new *states.State) (HookAction, error) {
 	return h.hook()
 }
 
+func (h *stopHook) StartAction(id HookActionIdentity) (HookAction, error) {
+	return h.hook()
+}
+
+func (h *stopHook) ProgressAction(id HookActionIdentity, progress string) (HookAction, error) {
+	return h.hook()
+}
+
+func (h *stopHook) CompleteAction(id HookActionIdentity, err error) (HookAction, error) {
+	return h.hook()
+}
+
 func (h *stopHook) hook() (HookAction, error) {
 	if h.Stopped() {
 		return HookActionHalt, errors.New("execution halted")
