@@ -7,16 +7,18 @@ import (
 	"testing"
 
 	"github.com/hashicorp/hcl/v2/hcltest"
+	"github.com/zclconf/go-cty/cty"
+
 	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/configs"
 	"github.com/hashicorp/terraform/internal/instances"
+	"github.com/hashicorp/terraform/internal/resources/ephemeral"
 	"github.com/hashicorp/terraform/internal/states"
-	"github.com/zclconf/go-cty/cty"
 )
 
 func TestNodeExpandModuleExecute(t *testing.T) {
 	ctx := &MockEvalContext{
-		InstanceExpanderExpander: instances.NewExpander(),
+		InstanceExpanderExpander: instances.NewExpander(nil),
 	}
 	ctx.installSimpleEval()
 
@@ -42,7 +44,8 @@ func TestNodeCloseModuleExecute(t *testing.T) {
 		state := states.NewState()
 		state.EnsureModule(addrs.RootModuleInstance.Child("child", addrs.NoKey))
 		ctx := &MockEvalContext{
-			StateState: state.SyncWrapper(),
+			StateState:                  state.SyncWrapper(),
+			EphemeralResourcesResources: ephemeral.NewResources(),
 		}
 		node := nodeCloseModule{addrs.Module{"child"}}
 		diags := node.Execute(ctx, walkApply)
@@ -73,7 +76,8 @@ func TestNodeCloseModuleExecute(t *testing.T) {
 		state := states.NewState()
 		state.EnsureModule(addrs.RootModuleInstance.Child("child", addrs.NoKey))
 		ctx := &MockEvalContext{
-			StateState: state.SyncWrapper(),
+			StateState:                  state.SyncWrapper(),
+			EphemeralResourcesResources: ephemeral.NewResources(),
 		}
 		node := nodeCloseModule{addrs.Module{"child"}}
 
@@ -90,7 +94,7 @@ func TestNodeCloseModuleExecute(t *testing.T) {
 func TestNodeValidateModuleExecute(t *testing.T) {
 	t.Run("success", func(t *testing.T) {
 		ctx := &MockEvalContext{
-			InstanceExpanderExpander: instances.NewExpander(),
+			InstanceExpanderExpander: instances.NewExpander(nil),
 		}
 		ctx.installSimpleEval()
 		node := nodeValidateModule{
@@ -110,7 +114,7 @@ func TestNodeValidateModuleExecute(t *testing.T) {
 
 	t.Run("invalid count", func(t *testing.T) {
 		ctx := &MockEvalContext{
-			InstanceExpanderExpander: instances.NewExpander(),
+			InstanceExpanderExpander: instances.NewExpander(nil),
 		}
 		ctx.installSimpleEval()
 		node := nodeValidateModule{
