@@ -7,9 +7,12 @@ import (
 	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/configs/configschema"
 	"github.com/hashicorp/terraform/internal/providers"
+	"github.com/hashicorp/terraform/internal/providers/testing"
+	"github.com/hashicorp/terraform/internal/schemarepo"
+	"github.com/hashicorp/terraform/internal/schemarepo/loadschemas"
 )
 
-func simpleTestSchemas() *Schemas {
+func simpleTestSchemas() *schemarepo.Schemas {
 	provider := simpleMockProvider()
 	provisioner := simpleMockProvisioner()
 
@@ -31,13 +34,13 @@ func simpleTestSchemas() *Schemas {
 // The intended use for this is in testing components that use schemas to
 // drive other behavior, such as reference analysis during graph construction,
 // but that don't actually need to interact with providers otherwise.
-func schemaOnlyProvidersForTesting(schemas map[addrs.Provider]providers.ProviderSchema) *contextPlugins {
+func schemaOnlyProvidersForTesting(schemas map[addrs.Provider]providers.ProviderSchema) *loadschemas.Plugins {
 	factories := make(map[addrs.Provider]providers.Factory, len(schemas))
 
 	for providerAddr, schema := range schemas {
 		schema := schema
 
-		provider := &MockProvider{
+		provider := &testing.MockProvider{
 			GetProviderSchemaResponse: &schema,
 		}
 
@@ -46,5 +49,5 @@ func schemaOnlyProvidersForTesting(schemas map[addrs.Provider]providers.Provider
 		}
 	}
 
-	return newContextPlugins(factories, nil)
+	return newContextPlugins(factories, nil, nil)
 }
