@@ -139,7 +139,7 @@ func testModuleInline(t testing.TB, sources map[string]string) *configs.Config {
 		t.Fatalf("failed to refresh modules after installation: %s", err)
 	}
 
-	config, diags := loader.LoadConfigWithTests(cfgPath, "tests")
+	config, diags := loader.LoadConfig(cfgPath, configs.MatchTestFiles("tests"))
 	if diags.HasErrors() {
 		t.Fatal(diags.Error())
 	}
