@@ -6,6 +6,7 @@ package terraform
 import (
 	"log"
 
+	"github.com/hashicorp/terraform/internal/addrs"
 	"github.com/hashicorp/terraform/internal/configs"
 	"github.com/hashicorp/terraform/internal/dag"
 )
@@ -15,8 +16,11 @@ import (
 type GraphNodeAttachResourceConfig interface {
 	GraphNodeConfigResource
 
-	// Sets the configuration
-	AttachResourceConfig(*configs.Resource)
+	// Sets the configuration, either to a present resource block or to
+	// a "removed" block commemorating a resource that has since been
+	// removed. Callers should always leave at least one of these
+	// arguments set to nil.
+	AttachResourceConfig(*configs.Resource, *configs.Removed)
 }
 
 // AttachResourceConfigTransformer goes through the graph and attaches
@@ -30,6 +34,22 @@ type AttachResourceConfigTransformer struct {
 }
 
 func (t *AttachResourceConfigTransformer) Transform(g *Graph) error {
+	// Collect removed blocks to attach to any resources. These are collected
+	// independently because removed blocks may live in a parent module of the
+	// resource referenced.
+	removed := addrs.MakeMap[addrs.ConfigResource, *configs.Removed]()
+
+	t.Config.DeepEach(func(c *configs.Config) {
+		for _, rem := range c.Module.Removed {
+			resAddr, ok := rem.From.RelSubject.(addrs.ConfigResource)
+			if !ok {
+				// Not for a resource at all, so can't possibly match.
+				// Non-resource removed targets have nothing to attach.
+				continue
+			}
+			removed.Put(resAddr, rem)
+		}
+	})
 
 	// Go through and find GraphNodeAttachResource
 	for _, v := range g.Vertices() {
@@ -42,69 +62,30 @@ func (t *AttachResourceConfigTransformer) Transform(g *Graph) error {
 		// Determine what we're looking for
 		addr := arn.ResourceAddr()
 
+		// Check for a removed block first, since that would preclude any resource config.
+		if remCfg, ok := removed.GetOk(addr); ok {
+			log.Printf("[TRACE] AttachResourceConfigTransformer: attaching to %q (%T) removed block from %#v", dag.VertexName(v), v, remCfg.DeclRange)
+			arn.AttachResourceConfig(nil, remCfg)
+		}
+
 		// Get the configuration.
-		config := t.Config.Descendent(addr.Module)
+		config := t.Config.Descendant(addr.Module)
+
 		if config == nil {
 			log.Printf("[TRACE] AttachResourceConfigTransformer: %q (%T) has no configuration available", dag.VertexName(v), v)
 			continue
 		}
 
-		for _, r := range config.Module.ManagedResources {
-			rAddr := r.Addr()
-
-			if rAddr != addr.Resource {
-				// Not the same resource
-				continue
-			}
-
-			log.Printf("[TRACE] AttachResourceConfigTransformer: attaching to %q (%T) config from %s", dag.VertexName(v), v, r.DeclRange)
-			arn.AttachResourceConfig(r)
-
-			// attach the provider_meta info
-			if gnapmc, ok := v.(GraphNodeAttachProviderMetaConfigs); ok {
-				log.Printf("[TRACE] AttachResourceConfigTransformer: attaching provider meta configs to %s", dag.VertexName(v))
-				if config == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no config set on the transformer for %s", dag.VertexName(v))
-					continue
-				}
-				if config.Module == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no module in config for %s", dag.VertexName(v))
-					continue
-				}
-				if config.Module.ProviderMetas == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no provider metas defined for %s", dag.VertexName(v))
-					continue
-				}
-				gnapmc.AttachProviderMetaConfigs(config.Module.ProviderMetas)
-			}
-		}
-		for _, r := range config.Module.DataResources {
-			rAddr := r.Addr()
-
-			if rAddr != addr.Resource {
-				// Not the same resource
-				continue
-			}
-
+		if r := config.Module.ResourceByAddr(addr.Resource); r != nil {
 			log.Printf("[TRACE] AttachResourceConfigTransformer: attaching to %q (%T) config from %#v", dag.VertexName(v), v, r.DeclRange)
-			arn.AttachResourceConfig(r)
-
-			// attach the provider_meta info
+			arn.AttachResourceConfig(r, nil)
 			if gnapmc, ok := v.(GraphNodeAttachProviderMetaConfigs); ok {
 				log.Printf("[TRACE] AttachResourceConfigTransformer: attaching provider meta configs to %s", dag.VertexName(v))
-				if config == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no config set on the transformer for %s", dag.VertexName(v))
-					continue
+				if config.Module.ProviderMetas != nil {
+					gnapmc.AttachProviderMetaConfigs(config.Module.ProviderMetas)
+				} else {
+					log.Printf("[TRACE] AttachResourceConfigTransformer: no provider meta configs available to attach to %s", dag.VertexName(v))
 				}
-				if config.Module == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no module in config for %s", dag.VertexName(v))
-					continue
-				}
-				if config.Module.ProviderMetas == nil {
-					log.Printf("[TRACE] AttachResourceConfigTransformer: no provider metas defined for %s", dag.VertexName(v))
-					continue
-				}
-				gnapmc.AttachProviderMetaConfigs(config.Module.ProviderMetas)
 			}
 		}
 	}
