@@ -15,6 +15,13 @@ type diagnosticBase struct {
 	address  string
 }
 
+var _ Diagnostic = &diagnosticBase{}
+
+// diagnosticBase doesn't implement ComparableDiagnostic because the lack of source data
+// means separate diagnostics might be falsely identified as equal. This poses a user-facing
+// risk if deduplication of diagnostics removes a diagnostic that's incorrectly been identified
+// as a duplicate via comparison.
+
 func (d diagnosticBase) Severity() Severity {
 	return d.severity
 }
